@@ -214,8 +214,8 @@ function(x, digits = max(3, getOption("digits") - 3),
                     names = c("Min","1Q","Median","3Q","Max"))
     print(rq, digits = digits, ...)
     cat("\nCoefficient(s):\n")
-    print.coefmat(x$coef, digits = digits,
-                  signif.stars = signif.stars, ...)
+    printCoefmat(x$coef, digits = digits,
+                 signif.stars = signif.stars, ...)
     cat("\nDiagnostic Tests:")
     print(x$j.b.test)
     print(x$l.b.test)
